==> restidy-0.2.6.tar.gz: restidy-0.2.6/setup.py <==
#!/usr/bin/env python3
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: Jake Cui
# Mail: cqp@cau.edu.cn
# Created Time:  2022-02-10 19:17:34
#############################################

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup


requirements = [
    'numpy', 'pandas', 'setuptools'
]


setup(
    name="restidy",
    version="0.2.6",
    keywords=["pip", "wgs", "resfinder"],
    description="resfinder result tidy",
    long_description="Organize resfinder result to tabluar format",
    license="MIT Licence",
    url="https://github.com/hbucqp/restidy",
    author="Jake Cui",
    author_email="cqp@cau.edu.cn",
    packages=find_packages(),
    # include_package_data=True,
    package_data={'': ['*.tsv']},
    platforms="any",
    install_requires=requirements,
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 3 - Alpha',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.9',
    ],
    entry_points={
        'console_scripts': [
            'restidy=restidy.restidy:main',
        ],
    },
)

==> restidy-0.2.8.tar.gz: restidy-0.2.8/setup.py <==
#!/usr/bin/env python3
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: Jake Cui
# Mail: cqp@cau.edu.cn
# Created Time:  2022-02-10 19:17:34
#############################################

import os
import sys

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup


requirements = [
    'numpy', 'pandas', 'setuptools'
]


def read(rel_path: str) -> str:
    here = os.path.abspath(os.path.dirname(__file__))
    # intentionally *not* adding an encoding option to open, See:
    #   https://github.com/pypa/virtualenv/issues/201#issuecomment-3145690
    with open(os.path.join(here, rel_path)) as fp:
        return fp.read()


def get_version(rel_path: str) -> str:
    for line in read(rel_path).splitlines():
        if line.startswith("__version__"):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    raise RuntimeError("Unable to find version string.")


setup(
    name="restidy",
    version=get_version("restidy/__init__.py"),
    keywords=["pip", "wgs", "resfinder"],
    description="resfinder result tidy",
    long_description="Organize resfinder result to tabluar format",
    license="MIT Licence",
    url="https://github.com/hbucqp/restidy",
    author="Jake Cui",
    author_email="cqp@cau.edu.cn",
    packages=find_packages(),
    # include_package_data=True,
    package_data={'': ['*.tsv']},
    platforms="any",
    install_requires=requirements,
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 3 - Alpha',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.9',
    ],
    entry_points={
        'console_scripts': [
            'restidy=restidy.restidy:main',
        ],
    },
)
